#
# Makefile Template for Tessy
# Compiler: TI TMS 320
# Debugger: TI Code Composer Studio 4
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LIBRARY               :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-i
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s '$(TESSY_SYS)')
TI_HOME         := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
LINK_FILE_SHORT := $(shell ts_pathname -s '$(LINKER_FILE)')

TS_NAME         := TS_CCS4
IDE_NAME        := ccs4
COMPANY_NAME    := ti
PROCESSOR_NAME  := tms320

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : check_success master slave

# Cygwin work around.
S_BUILDIN_TESSY_FLAG := $(wildcard $(MODULE_PATH)/tslows_builtin.tessy)

check_success :
ifneq ($(S_BUILDIN_TESSY_FLAG),)
	@echo *
	@echo * Obviously the last build failed. Cleaning up built-in files...
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin.*
	@echo * Please, try again to generate a built-in target binary.
	@echo *
	@exit 1
endif

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE		:=	$(TESSY_SYS)/make/master_$(IDE_NAME)_16bit_gnu_i386.mk
S_COMM_MAKE		:=	$(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
#
# SLAVE
#

S_ASM          := $(TI_HOME)\bin\asm2000.exe -g
S_CC           := $(TI_HOME)\bin\cl2000.exe
S_LINK         := $(TI_HOME)\bin\cl2000.exe
S_INCLUDES     := -i"$(TESSY_SYS_DOS)\include\tessy\comm" -i"$(MODULE_PATH_DOS)" -i"$(TI_HOME)\include"
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)

# The following options correspond to the F28232 processor.
# (For the F28332 processor add option '--float_support=fpu32' (without the ticks) to
# S_COMP_OPTIONS and choose rts2800_fpu32.lib as library within the TEE)
S_COMP_OPTIONS := --silicon_version=28 -g --cla_support=cla0 --include_path="$(TI_HOME)/include" --large_memory_model \
						--unified_memory --preproc_with_compile -pdw -DTESSY -DTS_CCS2 -DTS_SLAVE -D$(TS_BYTEORDER) -DTS_TMS320 \
						-DTS_TMS320C28xx -DTS_HAVE_FLOAT64 -DTS_HAVE_INT64 -DHAS_16BIT_UINT8
S_LINK_OPTIONS	:= --silicon_version=28 -g --cla_support=cla0 -z --stack_size=0x300 -i"$(TI_HOME)\lib" \
						-m"ts_$(TESTOBJECT).map" --reread_libs --rom_model

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -c "$<" -fr=$(MODULE_PATH_DOS)


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

ifneq ($(S_GenerateBuiltinData),)
TARGET_FLAG := d
BUILTIN_OBJ := $(MODULE_PATH_DOS)\tslows_builtin$(OBJFILE_EXTENSION)
master :
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin$(OBJFILE_EXTENSION)
else
BUILTIN_OBJ :=
TARGET_FLAG := s
master : $(MODULE_PATH)\ts_$(TESTOBJECT)_m.exe
endif
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION)

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -c $< -fr=$(MODULE_PATH_DOS)

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -c $< -fr=$(MODULE_PATH_DOS)


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)





#
#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -c $< -fr=$(MODULE_PATH_DOS)


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION) :  $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_C1_OBJECTS) \
															$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) -o $@ \
						$(USER_LINK_OPTIONS) $(S_OBJECTS) $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
						$(S_SRC_OBJECTS) $(S_UC_OBJECT) \
						$(S_STUB_OBJECT) $(S_C1_OBJECTS) \
						-m="$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG).map" \
						-l="$(LIBRARY)" $(LINK_FILE_SHORT)
ifneq ($(S_GenerateBuiltinData),)
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin*.*
	@echo *
	@echo * Generated target binary '$(MODULE_PATH)/ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION)' containing builtin data.
	@echo *
endif	
						

#####################################################################
#END_TARGETS
#####################################################################



